package Daje::Database::View::VToolsProjects;
use Mojo::Base 'Daje::Database::View::Super::VToolsProjects', -base, -signatures, -async_await;
use v5.40;

# NAME
# ====
#
# Daje::Database::View::VToolsProjects - It creates perl code
#
# SYNOPSIS
# ========
#
#     use Daje::Database::View::VToolsProjects;
#
# DESCRIPTION
# ===========
#
# Daje::Database::View::VToolsProjects is a module that retrieves data from a View
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#

1;